diff --git a/src/backend/utils/adt/ruleutils.c b/src/backend/utils/adt/ruleutils.c
index cdbdea2..54a2c87 100644
--- a/src/backend/utils/adt/ruleutils.c
+++ b/src/backend/utils/adt/ruleutils.c
@@ -6024,70 +6024,36 @@ get_from_clause_item(Node *jtnode, Query *query, deparse_context *context)
 
 		get_from_clause_item(j->larg, query, context);
 
-		if (j->isNatural)
+		switch (j->jointype)
 		{
-			if (!PRETTY_INDENT(context))
-				appendStringInfoChar(buf, ' ');
-			switch (j->jointype)
-			{
-				case JOIN_INNER:
-					appendContextKeyword(context, "NATURAL JOIN ",
-										 -PRETTYINDENT_JOIN,
-										 PRETTYINDENT_JOIN, 0);
-					break;
-				case JOIN_LEFT:
-					appendContextKeyword(context, "NATURAL LEFT JOIN ",
-										 -PRETTYINDENT_JOIN,
-										 PRETTYINDENT_JOIN, 0);
-					break;
-				case JOIN_FULL:
-					appendContextKeyword(context, "NATURAL FULL JOIN ",
-										 -PRETTYINDENT_JOIN,
-										 PRETTYINDENT_JOIN, 0);
-					break;
-				case JOIN_RIGHT:
-					appendContextKeyword(context, "NATURAL RIGHT JOIN ",
-										 -PRETTYINDENT_JOIN,
-										 PRETTYINDENT_JOIN, 0);
-					break;
-				default:
-					elog(ERROR, "unrecognized join type: %d",
-						 (int) j->jointype);
-			}
-		}
-		else
-		{
-			switch (j->jointype)
-			{
-				case JOIN_INNER:
-					if (j->quals)
-						appendContextKeyword(context, " JOIN ",
-											 -PRETTYINDENT_JOIN,
-											 PRETTYINDENT_JOIN, 2);
-					else
-						appendContextKeyword(context, " CROSS JOIN ",
-											 -PRETTYINDENT_JOIN,
-											 PRETTYINDENT_JOIN, 1);
-					break;
-				case JOIN_LEFT:
-					appendContextKeyword(context, " LEFT JOIN ",
-										 -PRETTYINDENT_JOIN,
-										 PRETTYINDENT_JOIN, 2);
-					break;
-				case JOIN_FULL:
-					appendContextKeyword(context, " FULL JOIN ",
+			case JOIN_INNER:
+				if (j->quals)
+					appendContextKeyword(context, " JOIN ",
 										 -PRETTYINDENT_JOIN,
 										 PRETTYINDENT_JOIN, 2);
-					break;
-				case JOIN_RIGHT:
-					appendContextKeyword(context, " RIGHT JOIN ",
+				else
+					appendContextKeyword(context, " CROSS JOIN ",
 										 -PRETTYINDENT_JOIN,
-										 PRETTYINDENT_JOIN, 2);
-					break;
-				default:
-					elog(ERROR, "unrecognized join type: %d",
-						 (int) j->jointype);
-			}
+										 PRETTYINDENT_JOIN, 1);
+				break;
+			case JOIN_LEFT:
+				appendContextKeyword(context, " LEFT JOIN ",
+									 -PRETTYINDENT_JOIN,
+									 PRETTYINDENT_JOIN, 2);
+				break;
+			case JOIN_FULL:
+				appendContextKeyword(context, " FULL JOIN ",
+									 -PRETTYINDENT_JOIN,
+									 PRETTYINDENT_JOIN, 2);
+				break;
+			case JOIN_RIGHT:
+				appendContextKeyword(context, " RIGHT JOIN ",
+									 -PRETTYINDENT_JOIN,
+									 PRETTYINDENT_JOIN, 2);
+				break;
+			default:
+				elog(ERROR, "unrecognized join type: %d",
+					 (int) j->jointype);
 		}
 
 		if (need_paren_on_right)
@@ -6098,31 +6064,14 @@ get_from_clause_item(Node *jtnode, Query *query, deparse_context *context)
 
 		context->indentLevel -= PRETTYINDENT_JOIN_ON;
 
-		if (!j->isNatural)
+		if (j->quals)
 		{
-			if (j->usingClause)
-			{
-				ListCell   *col;
-
-				appendStringInfo(buf, " USING (");
-				foreach(col, j->usingClause)
-				{
-					if (col != list_head(j->usingClause))
-						appendStringInfo(buf, ", ");
-					appendStringInfoString(buf,
-									  quote_identifier(strVal(lfirst(col))));
-				}
+			appendStringInfo(buf, " ON ");
+			if (!PRETTY_PAREN(context))
+				appendStringInfoChar(buf, '(');
+			get_rule_expr(j->quals, context, false);
+			if (!PRETTY_PAREN(context))
 				appendStringInfoChar(buf, ')');
-			}
-			else if (j->quals)
-			{
-				appendStringInfo(buf, " ON ");
-				if (!PRETTY_PAREN(context))
-					appendStringInfoChar(buf, '(');
-				get_rule_expr(j->quals, context, false);
-				if (!PRETTY_PAREN(context))
-					appendStringInfoChar(buf, ')');
-			}
 		}
 		if (!PRETTY_PAREN(context) || j->alias != NULL)
 			appendStringInfoChar(buf, ')');
